package com.migao.config.mvc;


import com.migao.config.authority.AuthenticationInterceptor;
import com.migao.config.authority.AuthenticationProperties;
import com.migao.config.authority.AuthorityInterceptor;
import com.migao.config.constant.SystemConstant;
import com.migao.config.properties.SystemProperties;
import com.migao.util.FileUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.Ordered;
import org.springframework.format.FormatterRegistry;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.ResourceHandlerRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

import javax.annotation.Resource;
import java.io.File;
import java.io.IOException;

@Configuration
@Slf4j
public class WebMvcConfig implements WebMvcConfigurer {

    @Autowired
    private AuthenticationInterceptor authenticationInterceptor;
    @Autowired
    private AuthorityInterceptor authorityInterceptor;
    @Autowired
    private AuthenticationProperties authenticationProperties;
    @Resource
    private SystemProperties systemProperties;

    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        //认证
        registry.addInterceptor(authenticationInterceptor).order(Ordered.LOWEST_PRECEDENCE - 1)
                .addPathPatterns("/**")
                .excludePathPatterns(authenticationProperties.getPermitUrlList());
        //鉴权
        registry.addInterceptor(authorityInterceptor).order(Ordered.LOWEST_PRECEDENCE)
                .addPathPatterns("/**")
                .excludePathPatterns(authenticationProperties.getPermitUrlList());

    }

    @Override
    public void addResourceHandlers(ResourceHandlerRegistry registry) {
        registry
                .addResourceHandler(
                        StringUtils.join(
                                SystemConstant.URI_CONCAT_SYMBOL,
                                systemProperties.getFileStoreDir(),
                                SystemConstant.URI_CONCAT_SYMBOL,
                                SystemConstant.URI_FULL_PATTERN_SYMBOL
                        )
                ).addResourceLocations(
                StringUtils.join(
                        SystemConstant.WEB_MVC_STATIC_RESOURCE_MAPPING_PREFIX,
                        FileUtils.getApplicationRootPath(),
                        SystemConstant.URI_CONCAT_SYMBOL,
                        systemProperties.getFileStoreDir(),
                        SystemConstant.URI_CONCAT_SYMBOL
                ));
    }

}
